/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef _SHSIGN_H_
#define _SHSIGN_H_

#define SGN_SUFFIX ".chk"
#define  NSS_SIGN_CHK_MAGIC1 0xf1
#define  NSS_SIGN_CHK_MAGIC2 0xc5
#define  NSS_SIGN_CHK_MAJOR_VERSION 0x01
#define  NSS_SIGN_CHK_MINOR_VERSION 0x02

#endif /* _SHSIGN_H_ */
